.. _Python: https://www.python.org/
.. _Django: https://www.djangoproject.com/
.. _django-smart-media: https://github.com/sveetch/django-smart-media
.. _django-configuration: https://django-configurations.readthedocs.io/en/stable/

Django Firm Info
================

A Django application package for storage firm info


Features
********

* Full test coverage;
* Included class for default settings with `django-configuration`_ (this is optional);


Dependancies
************

* `Python`_>=3.8;
* `Django`_>=3.2;
* `django-smart-media`_>=0.3.0;


Links
*****

* Read the documentation on `Read the docs <https://django-firm-info.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/django-firm-info>`_;
* Clone it on its `Github repository <https://github.com/emencia/django-firm-info>`_;
